@@ -14,6 +14,7 @@
 
 import getpass
 import re
+from typing import Union
 
 import click
 from requests import HTTPError
@@ -79,7 +80,10 @@ def determine_package_name_and_version(ctx: TagContext) -> None:
 
 def get_release_notes(ctx: TagContext) -> None:
     click.secho("> Grabbing the release notes.", fg="cyan")
-    if "google-cloud-ruby" in ctx.upstream_repo:
+    if (
+        "google-cloud-ruby" in ctx.upstream_repo
+        or "google-api-ruby-client" in ctx.upstream_repo
+    ):
         changelog_file = f"{ctx.package_name}/CHANGELOG.md"
     else:
         changelog_file = "CHANGELOG.md"
@@ -124,6 +128,34 @@ def create_release(ctx: TagContext) -> None:
     )
 
 
+def kokoro_job_name(upstream_repo: str, package_name: str) -> Union[str, None]:
+    """Return the Kokoro job name.
+
+    Args:
+        upstream_repo (str): The GitHub repo in the form of `<owner>/<repo>`
+        package_name (str): The name of package to release
+
+    Returns:
+        The name of the Kokoro job to trigger or None if there is no job to trigger
+    """
+    if "google-cloud-ruby" in upstream_repo:
+        return "cloud-devrel/client-libraries/google-cloud-ruby/release"
+    elif "google-api-ruby-client" in upstream_repo:
+        return f"cloud-devrel/client-libraries/google-api-ruby-client/release/{package_name}"
+    else:
+        return f"cloud-devrel/client-libraries/{package_name}/release"
+
+
+def package_name(pull: dict) -> Union[str, None]:
+    head_ref = pull["head"]["ref"]
+    click.secho(f"PR head ref is {head_ref}")
+    match = re.match(r"release-(.+)-v(\d+\.\d+\.\d+)", head_ref)
+    if match is None:
+        return None
+
+    return match.group(1)
+
+
 def tag(ctx: TagContext = None) -> TagContext:
     if not ctx:
         ctx = TagContext()
@@ -150,17 +182,7 @@ def tag(ctx: TagContext = None) -> TagContext:
     get_release_notes(ctx)
 
     create_release(ctx)
-
-    job_name = ctx.package_name.split("google-cloud-")[-1]
-
-    if "google-cloud-ruby" in ctx.upstream_repo:
-        ctx.kokoro_job_name = (
-            f"cloud-devrel/client-libraries/google-cloud-ruby/release/{job_name}"
-        )
-    else:
-        ctx.kokoro_job_name = (
-            f"cloud-devrel/client-libraries/{ctx.package_name}/release"
-        )
+    ctx.kokoro_job_name = kokoro_job_name(ctx.upstream_repo, ctx.package_name)
 
     releasetool.commands.common.publish_via_kokoro(ctx)
 
